@@ -2,4 +2,4 @@
   "solarized-theme"
   "1.2.2"
   "The Solarized color theme, ported to Emacs."
-  '((dash "2.6.0")))
+  '((emacs "24.1") (cl-lib "0.5") (dash "2.6.0")))
